@@ -1,4 +1,4 @@
-from .GraphQLClient import GraphQLClient
+from .GraphQLClient import GraphQLClient, GQLResponseException
 from .QueryParser import QueryParser
 from .MutationParser import MutationParser
 from .SubscriptionParser import SubscriptionParser
@@ -6,5 +6,5 @@ from .helper_modules.Singleton import Singleton
 
 # * Package name:
 name = 'pygqlc'
-# * required here for pypi upload exceptions:
+
 from .__version__ import __version__
